@@ -635,7 +635,8 @@ def stats(limit, facets, filename, query):
 @click.option('--alert', help='The network alert ID or "all" to subscribe to all network alerts on your account.', default=None, type=str)
 @click.option('--tags', help='A comma-separated list of tags to grab data on.', default=None, type=str)
 @click.option('--compresslevel', help='The gzip compression level (0-9; 0 = no compression, 9 = most compression', default=9, type=int)
-def stream(color, fields, separator, limit, datadir, ports, quiet, timeout, streamer, countries, asn, alert, tags, compresslevel):
+@click.option('--vulns', help='A comma-separated list of vulnerabilities to grab data on.', default=None, type=str)
+def stream(color, fields, separator, limit, datadir, ports, quiet, timeout, streamer, countries, asn, alert, tags, compresslevel, vulns):
     """Stream data in real-time."""
     # Setup the Shodan API
     key = get_api_key()
@@ -663,9 +664,11 @@ def stream(color, fields, separator, limit, datadir, ports, quiet, timeout, stre
         stream_type.append('alert')
     if tags:
         stream_type.append('tags')
+    if vulns:
+        stream_type.append('vulns')
 
     if len(stream_type) > 1:
-        raise click.ClickException('Please use --ports, --countries, --tags OR --asn. You cant subscribe to multiple filtered streams at once.')
+        raise click.ClickException('Please use --ports, --countries, --tags, --vulns OR --asn. You cant subscribe to multiple filtered streams at once.')
 
     stream_args = None
 
@@ -689,6 +692,9 @@ def stream(color, fields, separator, limit, datadir, ports, quiet, timeout, stre
     
     if tags:
         stream_args = tags.split(',')
+    
+    if vulns:
+        stream_args = vulns.split(',')
 
     # Flatten the list of stream types
     # Possible values are:
@@ -710,6 +716,7 @@ def stream(color, fields, separator, limit, datadir, ports, quiet, timeout, stre
             'countries': api.stream.countries(args, timeout=timeout),
             'ports': api.stream.ports(args, timeout=timeout),
             'tags': api.stream.tags(args, timeout=timeout),
+            'vulns': api.stream.vulns(args, timeout=timeout),
         }.get(name, 'all')
 
     stream = _create_stream(stream_type, stream_args, timeout=timeout)
